@@ -29,7 +29,7 @@ class SNPsTxtEntry(object) :
 	
 	def __getitem__(self, fieldName):
 		"""Returns the value of field 'fieldName'"""
-		return self.values[field]
+		return self.values[fieldName]
 	
 	def __setitem__(self, fieldName, value) :
 		"""Sets the value of field 'fieldName' to 'value' """
@@ -39,7 +39,8 @@ class SNPsTxtEntry(object) :
 		return str(self.values)
 	
 class SNPsTxtFile(object) :
-	"""Represents a whole casava's snps.txt file::
+	"""
+	Represents a whole casava's snps.txt file::
 		
 		f = SNPsTxtFile('snps.txt')
 		for line in f :
